@@ -1,11 +1,11 @@
 /*
- * functions.h  -- ePiX auxiliary functions
+ * functions.h  -- ePiX auxiliary functions; Deriv, Integral classes
  *
  * This file is part of ePiX, a C++ library for creating high-quality 
- * figures in LaTeX
+ * figures in LaTeX 
  *
- * Version 1.0.23
- * Last Change: January 29, 2007
+ * Version 1.1.22
+ * Last Change: September 24, 2007
  */
 
 /* 
@@ -35,28 +35,11 @@
 #ifndef EPIX_FUNCTIONS
 #define EPIX_FUNCTIONS
 
-#include "globals.h"
-
 namespace ePiX {
 
   class P;
 
-  // ePiX:: trig functions are sensitive to angle units
-  double cos(double);
-  double sin(double);
-  double tan(double); 
-
-  // non-mathematical behavior (i.e. vanishing:) at poles
-  double sec(double);
-  double csc(double);
-  double cot(double);
-
-  // and inverses
-  double acos(double);
-  double asin(double);
-  double atan(double);
-
-  // more sanely-named aliases
+  // sensitive to angle units
   double Cos(double t);
   double Sin(double t);
   double Tan(double t);
@@ -69,6 +52,8 @@ namespace ePiX {
   double Asin(double t);
   double Atan(double t);
 
+  double Atan2(double y, double x);
+
   // additional hyperbolic functions and inverses
   double sech(double);
   double csch(double);
@@ -78,34 +63,31 @@ namespace ePiX {
   double acsch(double);
   double acoth(double);
 
-  // identity and zero functions, coordinate projections
-  template<class T>T id(T arg) { return arg; }
-  template<class T>double zero(T arg) { return 0; }
-  template<class T>double zero(T arg1, T arg2) { return 0; }
-
-  template<class T1, class T2>T1 proj1(T1 arg1, T2 arg2) { return arg1; }
-  template<class T1, class T2>T2 proj2(T1 arg1, T2 arg2) { return arg2; }
+  // zero functions
+  double zero(double);
+  double zero(double, double);
+  double zero(double, double, double);
+  double zero(const P&);
 
   // P constructors
   P xyz(double x, double y, double z=0);
   P cyl(double r, double t, double z);
   P sph(double r, double t, double phi);
 
-  P cylindrical(P arg);
-  P spherical(P arg);
-
-  P polar(double r, double t);
-  P cis(double t);
-
   // for log data plotting
   P log_log(double x, double y, double z=0);
   P log_lin(double x, double y, double z=0);
   P lin_log(double x, double y, double z=0);
 
-  double clip_to_unit(double t);
-  // utility functions with discontinuities removed
+  P cylindrical(P); // not const P&
+  P spherical(P);
+
+  P polar(double r, double t);
+  P cis(double t);
+
+  // utility functions
   double recip (double);
-  double sinx (double);
+  double sinx (double); // discontinuity removed
   double sgn (double);
 
   // period-2 extension of absolute value on [-1,1]: \/\/\/
@@ -113,37 +95,15 @@ namespace ePiX {
 
   int gcd (int, int);
 
-  // Scattered calls compare (e.g.) int to float
-  // template<class T>T min(T a, T b) { return a < b ? a : b; }
-  // template<class T>T max(T a, T b) { return b < a ? a : b; }
+  double min(double, double);
+  double max(double, double);
 
-  double min(const double, const double);
-  double max(const double, const double);
-
-  double snip_to(double var, const double arg1, const double arg2);
+  double snip_to(double var, double arg1, double arg2);
 
   double inf (double f(double), double, double);
   double sup (double f(double), double, double);
 
 
-  /*
-  // constant functions
-  class Const {
-  private:
-    double value;
-
-  public:
-    Const(double val=0) { value = val; }
-    double operator() (double t) { return value; }
-  }; // end of class Const
-  */
-
-  // derivative and integral operators for functions of one variable
-  template<class T> T deriv(T f(double), double t, double dt=EPIX_EPSILON)
-  {
-    return (1.0/dt)*(f(t+0.5*dt) - f(t-0.5*dt));
-  }
-
   // derivative class
   class Deriv {
   private:
@@ -151,16 +111,17 @@ namespace ePiX {
     double dt;
 
   public:
-    Deriv(double func(double), const double eps=EPIX_EPSILON);
+    Deriv(double func(double));
+    Deriv(double func(double), double eps);
 
     P operator() (const P&) const; // for plotting
 
     // numerical values
-    double eval(const double t) const;
+    double eval(double t) const;
 
     // one-sided derivatives
-    double right(const double t) const;
-    double left(const double t) const;
+    double right(double t) const;
+    double left(double t) const;
   }; // end of class Deriv
 
 
@@ -175,12 +136,8 @@ namespace ePiX {
 
     P operator() (const P&) const;
 
-    double eval(const double) const;
-  }; // end of class I
-
-  // compatibility aliases
-  typedef Deriv D;
-  typedef Integral I;
+    double eval(double) const;
+  }; // end of class Integral
 
   double newton (double f(double), double g(double), double start);
   double newton (double f(double), double start);
