@@ -4,12 +4,12 @@
  * This file is part of ePiX, a C++ library for creating high-quality
  * figures in LaTeX
  *
- * Version 1.1.18
- * Last Change: September 14, 2007
+ * Version 1.2.5
+ * Last Change: June 18, 2008
  */
 
 /*
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -40,6 +40,8 @@
 #include "triples.h"
 #include "frame.h"
 
+#include "map.h"
+
 #include "camera.h"
 #include "Color.h"
 
@@ -55,8 +57,6 @@ namespace ePiX {
 
   typedef std::list<domain>::const_iterator dolci;
 
-  static double id(double x) { return x; }
-
   scenery::scenery() : m_cull(0) { }
 
   scenery::scenery(P F(double, double), const domain& R) : m_cull(0)
