@@ -4,12 +4,12 @@
  * This file is part of ePiX, a C++ library for creating high-quality
  * figures in LaTeX
  *
- * Version 1.1.18
- * Last Change: September 15, 2007
+ * Version 1.2.5
+ * Last Change: June 18, 2008
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -43,12 +43,12 @@ namespace ePiX {
 
   const std::string epix_version()
   {
-    return "1.2.4";
+    return "1.2.6";
   }
 
   double truncate(double arg)
   {
-    return fabs(arg) < EPIX_EPSILON ? 0 : arg;
+    return fabs(arg) < 0.0001 ? 0 : arg; // 10^-4, avoid exponential notation
   }
 
   std::string date_and_time()
